/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_Parser__VfoSMFvkiwD1X70wCdediw tyObject_Parser__VfoSMFvkiwD1X70wCdediw;
typedef struct tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw;
typedef struct tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tyObject_Token__TUeI5CB5zbppKJkmeKoDMw tyObject_Token__TUeI5CB5zbppKJkmeKoDMw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA;
typedef struct tyObject_TSym__3r34mwqcVmg5JFNmiaVncw tyObject_TSym__3r34mwqcVmg5JFNmiaVncw;
typedef struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw tySequence__IeU9azYSNIK3V9b36Ir6NZcw;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ {
  RootObj Sup;
NI bufpos;
NCSTRING buf;
NimStringDesc* bufStorage;
NI bufLen;
tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, void* ClE_0);
void* ClE_0;
} tyProc__9aGJhSmkuel6SMfp4pTpyXA;
struct tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw {
  tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ Sup;
NI32 fileIdx;
NI indentAhead;
NI currLineIndent;
NIM_BOOL strongSpaces;
NIM_BOOL allowTabs;
tyProc__9aGJhSmkuel6SMfp4pTpyXA errorHandler;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
typedef NU8 tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw;
typedef NU8 tyEnum_NumericalBase__TH9auiUrNz9bAsj4cpFtJS5Q;
struct tyObject_Token__TUeI5CB5zbppKJkmeKoDMw {
tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw tokType;
NI indent;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
NI64 iNumber;
NF fNumber;
tyEnum_NumericalBase__TH9auiUrNz9bAsj4cpFtJS5Q base;
NI8 strongSpaceA;
NI8 strongSpaceB;
NimStringDesc* literal;
NI line;
NI col;
};
struct tyObject_Parser__VfoSMFvkiwD1X70wCdediw {
NI currInd;
NIM_BOOL firstTok;
NIM_BOOL hasProgress;
tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw lex;
tyObject_Token__TUeI5CB5zbppKJkmeKoDMw tok;
NI lineStartPrevious;
NI lineNumberPrevious;
NI bufposPrevious;
NI inPragma;
NI inSemiStmtList;
tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* emptyNode;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU32 tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg;
typedef NU8 tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw;
struct tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw {
tyObject_TType__kQDDJGUiaUAtO9c9b6LjZYjA* typ;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
tySet_tyEnum_TNodeFlag__0RUKWdbLPY3l0smKVGDLMg flags;
tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__3r34mwqcVmg5JFNmiaVncw* sym;
} _kind_4;
struct {tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
} _kind_5;
struct {tySequence__IeU9azYSNIK3V9b36Ir6NZcw* sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TLLStreamKind__ChicJ77mD7SkMUxz402udA;
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s, void* buf, NI bufLen, void* ClE_0);
void* ClE_0;
} tyProc__M3d9crIwWf7vcamB5Yms8GQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__HzVCwACFYM9cx9aV62PdjtuA;
struct tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg {
  RootObj Sup;
tyEnum_TLLStreamKind__ChicJ77mD7SkMUxz402udA kind;
FILE* f;
NimStringDesc* s;
NI rd;
NI wr;
NI lineOffset;
tyProc__M3d9crIwWf7vcamB5Yms8GQ repl;
tyProc__HzVCwACFYM9cx9aV62PdjtuA onPrompt;
};
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU8 tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg;
typedef NU16 tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA;
typedef NU8 tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA;
typedef NU8 tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ;
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tySequence__IeU9azYSNIK3V9b36Ir6NZcw {
  TGenericSeq Sup;
  tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, objectInit)(void* dest, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, setupParser__syntaxes_209)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, NI32 fileIdx, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toFullPathConsiderDirty__msgs_581)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NI32 fileIdx);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__systemZio_389)(FILE** f, NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, openParser__syntaxes_189)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, NI32 fileIdx, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputstream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parsePipe__syntaxes_38)(NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputStream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, newNode__ast_3289)(tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpen__llstream_69)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode);
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, llStreamReadLine__llstream_194)(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s, NimStringDesc** line);
N_LIB_PRIVATE N_NIMCALL(NI, utf8Bom__syntaxes_22)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsShebang__syntaxes_25)(NimStringDesc* s, NI i);
N_LIB_PRIVATE N_NIMCALL(void, openParser__parser_131)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputStream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpen__llstream_30)(NimStringDesc* data);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7786)(NimStringDesc* s, NI first);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parseAll__parser_37)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p);
N_LIB_PRIVATE N_NIMCALL(void, closeParser__parser_39)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p);
N_LIB_PRIVATE N_NIMCALL(void, llStreamClose__llstream_110)(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, evalPipe__syntaxes_145)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* start);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, applyFilter__syntaxes_126)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stdin_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg, getFilter__syntaxes_69)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringDesc* a, NimStringDesc* b);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getCallee__syntaxes_108)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, renderTree__renderer_46)(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, tySet_tyEnum_TRenderFlag__ppo9aY4M5jqJlCPC7ZH9bmwA renderFlags);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, filterTmpl__filter95tmpl_191)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stdin_0, NimStringDesc* filename, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, filterStrip__filters_98)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stdin_0, NimStringDesc* filename, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, filterReplace__filters_109)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stdin_0, NimStringDesc* filename, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* call);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_530)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA note);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_657)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ flags);
N_LIB_PRIVATE N_NIMCALL(void, openParser__parser_125)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, NI32 fileIdx, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputStream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpen__llstream_63)(FILE* f);
extern TNimType NTIparser__VfoSMFvkiwD1X70wCdediw_;
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__xy1U79cq9cILOyMzz14OxC9cQ_2, "cannot open file: ", 18);
STRING_LITERAL(TM__xy1U79cq9cILOyMzz14OxC9cQ_4, "/home/runner/work/nightlies/nightlies/nim/compiler/syntaxes.nim", 63);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__xy1U79cq9cILOyMzz14OxC9cQ_3 = {((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_4),
((NI) 126),
((NI) 14)}
;
STRING_LITERAL(TM__xy1U79cq9cILOyMzz14OxC9cQ_5, "|", 1);
N_LIB_PRIVATE TNimType NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_;
STRING_LITERAL(TM__xy1U79cq9cILOyMzz14OxC9cQ_9, "invalid filter: ", 16);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__xy1U79cq9cILOyMzz14OxC9cQ_10 = {((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_4),
((NI) 74),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__xy1U79cq9cILOyMzz14OxC9cQ_11 = {((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_4),
((NI) 91),
((NI) 16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__xy1U79cq9cILOyMzz14OxC9cQ_12 = {((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_4),
((NI) 93),
((NI) 16)}
;
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, utf8Bom__syntaxes_22)(NimStringDesc* s) {
	NI result;
	result = (NI)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = (((NI) 3) <= (s ? s->Sup.len : 0));
		if (!(T5_)) goto LA6_;
		T5_ = ((NU8)(s->data[((NI) 0)]) == (NU8)(239));
		LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = ((NU8)(s->data[((NI) 1)]) == (NU8)(187));
		LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = ((NU8)(s->data[((NI) 2)]) == (NU8)(191));
		LA8_: ;
		if (!T3_) goto LA9_;
		result = ((NI) 3);
	}
	goto LA1_;
	LA9_: ;
	{
		result = ((NI) 0);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsShebang__syntaxes_25)(NimStringDesc* s, NI i) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI j;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((NI)(i + ((NI) 1)) < (s ? s->Sup.len : 0));
		if (!(T4_)) goto LA5_;
		T4_ = ((NU8)(s->data[i]) == (NU8)(35));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((NU8)(s->data[(NI)(i + ((NI) 1))]) == (NU8)(33));
		LA6_: ;
		if (!T3_) goto LA7_;
		j = (NI)(i + ((NI) 2));
		{
			while (1) {
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = (j < (s ? s->Sup.len : 0));
				if (!(T11_)) goto LA12_;
				T11_ = (((NU8)(s->data[j])) == ((NU8)(32)) || ((NU8)(s->data[j])) == ((NU8)(9)) || ((NU8)(s->data[j])) == ((NU8)(11)) || ((NU8)(s->data[j])) == ((NU8)(13)) || ((NU8)(s->data[j])) == ((NU8)(10)) || ((NU8)(s->data[j])) == ((NU8)(12)));
				LA12_: ;
				if (!T11_) goto LA10;
				j += ((NI) 1);
			} LA10: ;
		}
		result = ((NU8)(s->data[j]) == (NU8)(47));
	}
	LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parsePipe__syntaxes_38)(NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputStream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s;
	result = NIM_NIL;
	result = newNode__ast_3289(((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1));
	s = llStreamOpen__llstream_69(filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
	{
		NimStringDesc* line;
		NIM_BOOL T5_;
		NI i;
		NI linenumber;
		if (!!((s == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA3_;
		line = rawNewString(((NI) 80));
		T5_ = (NIM_BOOL)0;
		T5_ = llStreamReadLine__llstream_194(s, (&line));
		(void)(T5_);
		i = utf8Bom__syntaxes_22(line);
		linenumber = ((NI) 1);
		{
			NIM_BOOL T8_;
			NIM_BOOL T11_;
			T8_ = (NIM_BOOL)0;
			T8_ = containsShebang__syntaxes_25(line, i);
			if (!T8_) goto LA9_;
			T11_ = (NIM_BOOL)0;
			T11_ = llStreamReadLine__llstream_194(s, (&line));
			(void)(T11_);
			i = ((NI) 0);
			linenumber += ((NI) 1);
		}
		LA9_: ;
		{
			NIM_BOOL T14_;
			NIM_BOOL T15_;
			tyObject_Parser__VfoSMFvkiwD1X70wCdediw p;
			NimStringDesc* T24_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* T25_;
			T14_ = (NIM_BOOL)0;
			T15_ = (NIM_BOOL)0;
			T15_ = ((NI)(i + ((NI) 1)) < (line ? line->Sup.len : 0));
			if (!(T15_)) goto LA16_;
			T15_ = ((NU8)(line->data[i]) == (NU8)(35));
			LA16_: ;
			T14_ = T15_;
			if (!(T14_)) goto LA17_;
			T14_ = ((NU8)(line->data[(NI)(i + ((NI) 1))]) == (NU8)(63));
			LA17_: ;
			if (!T14_) goto LA18_;
			i += ((NI) 2);
			{
				while (1) {
					NIM_BOOL T22_;
					T22_ = (NIM_BOOL)0;
					T22_ = (i < (line ? line->Sup.len : 0));
					if (!(T22_)) goto LA23_;
					T22_ = (((NU8)(line->data[i])) == ((NU8)(32)) || ((NU8)(line->data[i])) == ((NU8)(9)) || ((NU8)(line->data[i])) == ((NU8)(11)) || ((NU8)(line->data[i])) == ((NU8)(13)) || ((NU8)(line->data[i])) == ((NU8)(10)) || ((NU8)(line->data[i])) == ((NU8)(12)));
					LA23_: ;
					if (!T22_) goto LA21;
					i += ((NI) 1);
				} LA21: ;
			}
			nimZeroMem((void*)(&p), sizeof(tyObject_Parser__VfoSMFvkiwD1X70wCdediw));
			objectInit((&p), (&NTIparser__VfoSMFvkiwD1X70wCdediw_));
			T24_ = NIM_NIL;
			T24_ = substr__system_7786(line, i);
			T25_ = NIM_NIL;
			T25_ = llStreamOpen__llstream_30(T24_);
			openParser__parser_131((&p), filename, T25_, cache, config);
			result = parseAll__parser_37((&p));
			closeParser__parser_39((&p));
		}
		LA18_: ;
		llStreamClose__llstream_110(s);
	}
	LA3_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg, getFilter__syntaxes_69)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident) {
	tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg result;
{	result = (tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg)0;
	{
		tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg i;
		i = (tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg)0;
		{
			tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg v;
			NI res;
			v = (tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg)0;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= ((NI) 3))) goto LA4;
					v = ((tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg) (res));
					i = v;
					{
						NI T7_;
						T7_ = (NI)0;
						T7_ = nsuCmpIgnoreStyle((*ident).s, reprEnum((NI)i, (&NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_)));
						if (!(T7_ == ((NI) 0))) goto LA8_;
						result = i;
						goto BeforeRet_;
					}
					LA8_: ;
					res += ((NI) 1);
				} LA4: ;
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*, getCallee__syntaxes_108)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n) {
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* result;
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 27) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 30) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 31) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 26) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 28) || (*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 32));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident;
	}
	goto LA1_;
	LA5_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2))) goto LA8_;
		result = (*n)._kind_5.ident;
	}
	goto LA1_;
	LA8_: ;
	{
		NimStringDesc* T11_;
		NimStringDesc* T12_;
		T11_ = NIM_NIL;
		T12_ = NIM_NIL;
		T12_ = renderTree__renderer_46(n, 0);
		T11_ = rawNewString((T12_ ? T12_->Sup.len : 0) + 16);
appendString(T11_, ((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_9));
appendString(T11_, T12_);
		liMessage__msgs_1128(conf, (*n).info, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T11_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 0), TM__xy1U79cq9cILOyMzz14OxC9cQ_10, NIM_FALSE);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, applyFilter__syntaxes_126)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stdin_0) {
	tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* result;
	tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg f;
	tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = getCallee__syntaxes_108((*p).lex.config, n);
	f = getFilter__syntaxes_69(T1_);
	switch (f) {
	case ((tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg) 0):
	{
		result = stdin_0;
	}
	break;
	case ((tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg) 1):
	{
		result = filterTmpl__filter95tmpl_191((*p).lex.config, stdin_0, filename, n);
	}
	break;
	case ((tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg) 3):
	{
		result = filterStrip__filters_98((*p).lex.config, stdin_0, filename, n);
	}
	break;
	case ((tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg) 2):
	{
		result = filterReplace__filters_109((*p).lex.config, stdin_0, filename, n);
	}
	break;
	}
	{
		if (!!((f == ((tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg) 0)))) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = hasHint__options_530((*p).lex.config, ((tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA) 85));
			if (!T12_) goto LA13_;
			liMessage__msgs_1128((*p).lex.config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 85), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__xy1U79cq9cILOyMzz14OxC9cQ_11, NIM_FALSE);
			msgWriteln__msgs_657((*p).lex.config, (*result).s, 0);
			liMessage__msgs_1128((*p).lex.config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 86), ((NimStringDesc*) NIM_NIL), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__xy1U79cq9cILOyMzz14OxC9cQ_12, NIM_FALSE);
		}
		LA13_: ;
	}
	LA8_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, evalPipe__syntaxes_145)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* n, NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* start) {
	tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* result;
{	result = NIM_NIL;
	result = start;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 1))) goto LA3_;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29));
		if (!(T8_)) goto LA9_;
		T8_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 2));
		LA9_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA10_;
		T7_ = eqStrings((*(*(*n)._kind_6.sons->data[((NI) 0)])._kind_5.ident).s, ((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_5));
		LA10_: ;
		if (!T7_) goto LA11_;
		{
			NI i;
			NI res;
			i = (NI)0;
			res = ((NI) 1);
			{
				while (1) {
					if (!(res <= ((NI) 2))) goto LA15;
					i = res;
					{
						if (!((*(*n)._kind_6.sons->data[i]).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 29))) goto LA18_;
						result = evalPipe__syntaxes_145(p, (*n)._kind_6.sons->data[i], filename, result);
					}
					goto LA16_;
					LA18_: ;
					{
						result = applyFilter__syntaxes_126(p, (*n)._kind_6.sons->data[i], filename, result);
					}
					LA16_: ;
					res += ((NI) 1);
				} LA15: ;
			}
		}
	}
	goto LA5_;
	LA11_: ;
	{
		if (!((*n).kind == ((tyEnum_TNodeKind__clSgDh22o9au33BrVH9bDQZw) 115))) goto LA22_;
		result = evalPipe__syntaxes_145(p, (*n)._kind_6.sons->data[((NI) 0)], filename, result);
	}
	goto LA5_;
	LA22_: ;
	{
		result = applyFilter__syntaxes_126(p, n, filename, result);
	}
	LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, openParser__syntaxes_189)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, NI32 fileIdx, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputstream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NimStringDesc* filename;
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* pipe;
	tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s;
	filename = toFullPathConsiderDirty__msgs_581(config, fileIdx);
	pipe = parsePipe__syntaxes_38(filename, inputstream, cache, config);
	unsureAsgnRef((void**) (&(*p).lex.config), config);
	{
		if (!!((pipe == ((tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*) NIM_NIL)))) goto LA3_;
		s = evalPipe__syntaxes_145(p, pipe, filename, inputstream);
	}
	goto LA1_;
	LA3_: ;
	{
		s = inputstream;
	}
	LA1_: ;
	openParser__parser_125(p, fileIdx, s, cache, config);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, setupParser__syntaxes_209)(tyObject_Parser__VfoSMFvkiwD1X70wCdediw* p, NI32 fileIdx, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	NimStringDesc* filename;
	FILE* f;
	tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* T7_;
{	result = (NIM_BOOL)0;
	filename = toFullPathConsiderDirty__msgs_581(config, fileIdx);
	f = (FILE*)0;
	{
		NIM_BOOL T3_;
		NimStringDesc* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = open__systemZio_389(&f, filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0), ((NI) -1));
		if (!!(T3_)) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = rawNewString((filename ? filename->Sup.len : 0) + 18);
appendString(T6_, ((NimStringDesc*) &TM__xy1U79cq9cILOyMzz14OxC9cQ_2));
appendString(T6_, filename);
		liMessage__msgs_1128(config, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T6_, ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__xy1U79cq9cILOyMzz14OxC9cQ_3, NIM_FALSE);
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	LA4_: ;
	T7_ = NIM_NIL;
	T7_ = llStreamOpen__llstream_63(f);
	openParser__syntaxes_189(p, fileIdx, T7_, cache, config);
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw*, parseFile__syntaxes_217)(NI32 fileIdx, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	tyObject_TNode__uh9cWvEa5Ty85PXOtuP5emw* result;
	tyObject_Parser__VfoSMFvkiwD1X70wCdediw p;
	result = NIM_NIL;
	nimZeroMem((void*)(&p), sizeof(tyObject_Parser__VfoSMFvkiwD1X70wCdediw));
	objectInit((&p), (&NTIparser__VfoSMFvkiwD1X70wCdediw_));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = setupParser__syntaxes_209((&p), fileIdx, cache, config);
		if (!T3_) goto LA4_;
		result = parseAll__parser_37((&p));
		closeParser__parser_39((&p));
	}
	LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmsyntaxesdotnim_DatInit000)(void) {
static TNimNode* TM__xy1U79cq9cILOyMzz14OxC9cQ_6_4[4];
NI TM__xy1U79cq9cILOyMzz14OxC9cQ_8;
static char* NIM_CONST TM__xy1U79cq9cILOyMzz14OxC9cQ_7[4] = {
"none", 
"stdtmpl", 
"replace", 
"strip"};
static TNimNode TM__xy1U79cq9cILOyMzz14OxC9cQ_0[5];
NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_.size = sizeof(tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg);
NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_.align = NIM_ALIGNOF(tyEnum_FilterKind__jdW9apon5UQP4vZbSnVpojg);
NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_.kind = 14;
NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_.base = 0;
NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_.flags = 3;
for (TM__xy1U79cq9cILOyMzz14OxC9cQ_8 = 0; TM__xy1U79cq9cILOyMzz14OxC9cQ_8 < 4; TM__xy1U79cq9cILOyMzz14OxC9cQ_8++) {
TM__xy1U79cq9cILOyMzz14OxC9cQ_0[TM__xy1U79cq9cILOyMzz14OxC9cQ_8+0].kind = 1;
TM__xy1U79cq9cILOyMzz14OxC9cQ_0[TM__xy1U79cq9cILOyMzz14OxC9cQ_8+0].offset = TM__xy1U79cq9cILOyMzz14OxC9cQ_8;
TM__xy1U79cq9cILOyMzz14OxC9cQ_0[TM__xy1U79cq9cILOyMzz14OxC9cQ_8+0].name = TM__xy1U79cq9cILOyMzz14OxC9cQ_7[TM__xy1U79cq9cILOyMzz14OxC9cQ_8];
TM__xy1U79cq9cILOyMzz14OxC9cQ_6_4[TM__xy1U79cq9cILOyMzz14OxC9cQ_8] = &TM__xy1U79cq9cILOyMzz14OxC9cQ_0[TM__xy1U79cq9cILOyMzz14OxC9cQ_8+0];
}
TM__xy1U79cq9cILOyMzz14OxC9cQ_0[4].len = 4; TM__xy1U79cq9cILOyMzz14OxC9cQ_0[4].kind = 2; TM__xy1U79cq9cILOyMzz14OxC9cQ_0[4].sons = &TM__xy1U79cq9cILOyMzz14OxC9cQ_6_4[0];
NTIfilterkind__jdW9apon5UQP4vZbSnVpojg_.node = &TM__xy1U79cq9cILOyMzz14OxC9cQ_0[4];
}

